<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array("_97ea09a7f" . "af27c52c6e" . "ff69773df1" . "d8a" => base64_decode("dGltZX" . "N0YW1w"), "_44e986c04f4" . "1a08b56a383c" . "7b3a88ee2" => base64_decode("c2VuZG" . "Vy"), "_d706c160e45bf7434fff82a5976" . "f0e19" => base64_decode("YXJyYX" . "lfa2V5" . "cw=="), "_6e1c717cf3cbf1af982e" . "d74d4336b7f1" => base64_decode("Ym9keS1" . "odG1s"), "_f39f5346e313e4dd1ac3a7b" . "d8032beda" => base64_decode("c3Vic3RyX2NvbXBhcm" . "U="), "_9c050c786fc87170cbb84fc6a8b" . "13cb6" => base64_decode("YXR0YWNobWVudC0" . "="), "_1d6c68a0262e8fa" . "0bed1215b7224a98" . "e" => base64_decode("cmVjaXBpZW" . "50"), "_618a4aeb9fecc4592a" . "4521f34876fa29" => base64_decode("ZnJ" . "vbQ" . "=="), "_f589476007fa133f457c3ef29ddfa5" . "66" => base64_decode("VG8" . "="), "_956cd32298a229f9768" . "f1096f077ace3" => base64_decode("Ym9keS" . "1wbGFp" . "bg=="), "_8c575917cbaedf1e7" . "efae84939402bff" => base64_decode("U3Via" . "mVjdA" . "=="), "_a1e707d02a236dadebd" . "15a45e65ebdb6" => base64_decode("YXR0YWNo" . "bWVudC1j" . "b3VudA=="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_d706c160e45bf7434fff82a597" . "6f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_a1e707d02a236dadebd15a45e65ebdb" . "6"] && $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_f39f5346e313e4dd1" . "ac3a7bd8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_9c050c786fc87170cbb84fc6a8" . "b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_1d6c68a0262e8" . "fa0bed1215b722" . "4a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_618a4aeb" . "9fecc4592" . "a4521f348" . "76fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_f589476007fa133f457c3ef29" . "ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_8c575917cba" . "edf1e7efae84" . "939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_6e1c717cf3cbf1af9" . "82ed74d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_956cd32298a229f9768f1096f" . "077ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_97ea09a7faf27c52c6eff69773df" . "1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_44e986c04f41a08b56a383c" . "7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}