<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array("_a3d82c5df38e194c9c7" . "3e3ccb4223bbc" => base64_decode("ZW1haWxfZGF" . "0YQ=="), "_5d40a2cf1c525fb252b" . "f5599e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvam" . "VjdCB3YXMgaWRlbnRpZmllZCBm" . "b3IgbWFpbDsgc3ViamVjdCAn"), "_f656816961e8573806141c558b184f" . "e2" => base64_decode("c3V" . "iam" . "Vjd" . "A=="), "_9b16fa2683" . "095e67d7c8b" . "265a8081d0b" => base64_decode("TWFpbFJlY2VpdmVkR" . "XZlbnRSZWNlaXZlcg" . "=="), "_bfda889b74ea561b14325e30e7d7" . "5426" => base64_decode("Ym9keV" . "9odG1s"), "_67a0d624aebcceb0abd5ce56" . "a53ff06f" => base64_decode("ZGF0ZQ=" . "="), "_376d30c40857357a" . "4d4cbb1ffaa25817" => base64_decode("dG" . "8="), "_460e1aeb3113a1676ce59a8f4" . "0431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9" . "jYXB0dXJlIHByb2plY3Q="), "projec" . "t_id" => base64_decode("cHJvamVjdF9" . "pZA=="), "_03b1f0cee83" . "5582d1158dce" . "2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzdW" . "JzY3JpYmVy"), "_618a4aeb9fecc" . "4592a4521f3487" . "6fa29" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_e608e5b5c4c3" . "4a67ba97ef84c" . "1e16199" => base64_decode("Jw=" . "="), "_ced92d7b39" . "1285c8a2684" . "6f1f4bd3128" => base64_decode("Ym9keV90ZXh" . "0"), "_c35473364fa7a050299058f332ec29" . "c1" => base64_decode("ZXhjZXB0aW9" . "u"));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_9b16fa2683095e67d" . "7c8b265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_03b1f0cee835582d1158dce2678b505" . "c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_5d40a2cf1c525fb252bf559" . "9e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_e608e5b5c4c34a67ba9" . "7ef84c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_618a4aeb9" . "fecc4592a4" . "521f34876f" . "a29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_376d30c40857357a4d4cbb" . "1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_f656816961e8573806141c558b" . "184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_ced92d7b391285c8" . "a26846f1f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_bfda889b74ea561b14325e3" . "0e7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_67a0d624aebc" . "ceb0abd5ce56a" . "53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_460e1aeb3113a16" . "76ce59a8f40431d5" . "c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["project" . "_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_a3d82c5df38e194c9" . "c73e3ccb4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_c35473364fa7" . "a050299058f33" . "2ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}